{%- if user_id %}
  <img width="140" height="140" src="{{ user_photo_url(user_id, size=140) }}" class="media-object" alt=""/>
{%- endif %}

<input name="{{ field.name }}" type="file"
{%- for attr, val in attrs.items() %} {{ attr }}="{{ val }}"{%- endfor %}
/>
